@@ -40,9 +40,7 @@ _VALUE_PATTERN = re.compile(_VALUE_FORMAT)
 
 _TRACECONTEXT_MAXIMUM_TRACESTATE_KEYS = 32
 _delimiter_pattern = re.compile(r"[ \t]*,[ \t]*")
-_member_pattern = re.compile(
-    "({})(=)({})[ \t]*".format(_KEY_FORMAT, _VALUE_FORMAT)
-)
+_member_pattern = re.compile(f"({_KEY_FORMAT})(=)({_VALUE_FORMAT})[ \t]*")
 _logger = logging.getLogger(__name__)
 
 
@@ -245,7 +243,7 @@ class TraceState(typing.Mapping[str, str]):
 
     def __repr__(self) -> str:
         pairs = [
-            "{key=%s, value=%s}" % (key, value)
+            f"{{key={key}, value={value}}}"
             for key, value in self._dict.items()
         ]
         return str(pairs)
@@ -389,7 +387,8 @@ class TraceState(typing.Mapping[str, str]):
 
 
 DEFAULT_TRACE_STATE = TraceState.get_default()
-_TRACE_ID_HEX_LENGTH = 2 ** 128 - 1
+_TRACE_ID_MAX_VALUE = 2 ** 128 - 1
+_SPAN_ID_MAX_VALUE = 2 ** 64 - 1
 
 
 class SpanContext(
@@ -422,9 +421,8 @@ class SpanContext(
             trace_state = DEFAULT_TRACE_STATE
 
         is_valid = (
-            trace_id != INVALID_TRACE_ID
-            and span_id != INVALID_SPAN_ID
-            and trace_id < _TRACE_ID_HEX_LENGTH
+            INVALID_TRACE_ID < trace_id <= _TRACE_ID_MAX_VALUE
+            and INVALID_SPAN_ID < span_id <= _SPAN_ID_MAX_VALUE
         )
 
         return tuple.__new__(
@@ -478,16 +476,7 @@ class SpanContext(
         )
 
     def __repr__(self) -> str:
-        return (
-            "{}(trace_id=0x{}, span_id=0x{}, trace_flags=0x{:02x}, trace_state={!r}, is_remote={})"
-        ).format(
-            type(self).__name__,
-            format_trace_id(self.trace_id),
-            format_span_id(self.span_id),
-            self.trace_flags,
-            self.trace_state,
-            self.is_remote,
-        )
+        return f"{type(self).__name__}(trace_id=0x{format_trace_id(self.trace_id)}, span_id=0x{format_span_id(self.span_id)}, trace_flags=0x{self.trace_flags:02x}, trace_state={self.trace_state!r}, is_remote={self.is_remote})"
 
 
 class NonRecordingSpan(Span):
@@ -540,7 +529,7 @@ class NonRecordingSpan(Span):
         pass
 
     def __repr__(self) -> str:
-        return "NonRecordingSpan({!r})".format(self._context)
+        return f"NonRecordingSpan({self._context!r})"
 
 
 INVALID_SPAN_ID = 0x0000000000000000
